@@ -1,7 +1,10 @@
 #!/bin/bash
 
 npm run default
+npm run bundle
 npm run compile
+cp assets/lambda/tailscale-proxy/index.js lib/lambda/tailscale-proxy/index.js
+
 
 # For this proxy package to be used in the -caller project
 npm link
